@@ -584,6 +584,15 @@ class GrocyApiClient(object):
         if len(resp.content) > 0:
             return resp.json()
 
+    def _do_delete_request(self, end_url: str):
+        req_url = urljoin(self._base_url, end_url)
+        resp = requests.get(req_url, verify=self._verify_ssl, headers=self._headers)
+        if resp.status_code >= 400:
+            raise GrocyError(resp)
+
+        if len(resp.content) > 0:
+            return resp.json()
+
     def get_stock(self) -> List[CurrentStockResponse]:
         parsed_json = self._do_get_request("stock")
         return [CurrentStockResponse(response) for response in parsed_json]
@@ -742,9 +751,6 @@ class GrocyApiClient(object):
         if parsed_json:
             return RecipeDetailsResponse(parsed_json)
 
-    def add_generic(self, entity_type: str, data: object):
-        self._do_post_request(f"objects/{entity_type}", data)
-
     def get_batteries(self) -> List[CurrentBatteryResponse]:
         parsed_json = self._do_get_request(f"batteries")
         if parsed_json:
@@ -760,3 +766,15 @@ class GrocyApiClient(object):
         data = {"tracked_time": localized_tracked_time.isoformat()}
 
         return self._do_post_request(f"batteries/{battery_id}/charge", data)
+
+    def add_generic(self, entity_type: str, data):
+        return self._do_post_request(f"objects/{entity_type}", data)
+
+    def update_generic(self, entity_type: str, object_id: int, data):
+        return self._do_put_request(f"objects/{entity_type}/{object_id}", data)
+
+    def delete_generic(self, entity_type: str, object_id: int):
+        return self._do_delete_request(f"objects/{entity_type}/{object_id}")
+
+    def get_generic_objects_for_type(self, entity_type: str):
+        return self._do_get_request(f"objects/{entity_type}")
